public inbox for linux-bluetooth@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH BlueZ v1 1/3] adapter: Fix exposing coordinate sets if LE Audio is disabled
@ 2025-06-05 18:12 Luiz Augusto von Dentz
  2025-06-05 18:12 ` [PATCH BlueZ v1 2/3] client: Add assistant.list Luiz Augusto von Dentz
                   ` (3 more replies)
  0 siblings, 4 replies; 5+ messages in thread
From: Luiz Augusto von Dentz @ 2025-06-05 18:12 UTC (permalink / raw)
  To: linux-bluetooth

From: Luiz Augusto von Dentz <luiz.von.dentz@intel.com>

This fixes exposing non-discoverable coordinate set members if LE Audio
is disabled since it may lead system device setting showing them to user
that may attempt to pair them and end up not working.

Fixes: https://github.com/bluez/bluez/issues/523
---
 src/adapter.c | 9 +++++----
 1 file changed, 5 insertions(+), 4 deletions(-)

diff --git a/src/adapter.c b/src/adapter.c
index 2417e3cea960..70141e1542d7 100644
--- a/src/adapter.c
+++ b/src/adapter.c
@@ -7356,11 +7356,12 @@ void btd_adapter_device_found(struct btd_adapter *adapter,
 				MGMT_SETTING_ISO_SYNC_RECEIVER))
 			monitoring = true;
 
 		/* Monitor Devices advertising RSI since those can be
 		 * coordinated sets not marked as visible but their object are
 		 * needed.
 		 */
-		if (eir_data.rsi)
+		if (btd_adapter_has_exp_feature(adapter, EXP_FEAT_ISO_SOCKET) &&
+						eir_data.rsi)
 			monitoring = true;
 
 		if (!discoverable && !monitoring) {
@@ -7356,11 +7356,12 @@ void btd_adapter_device_found(struct btd_adapter *adapter,
 			monitoring = true;
 
-		/* Monitor Devices advertising RSI since those can be
-		 * coordinated sets not marked as visible but their object are
-		 * needed.
+		/* If ISO  Socket is enabled, monitor Devices advertising RSI
+		 * since those can be coordinated sets not marked as visible but
+		 * their object are needed.
 		 */
-- 
2.49.0


^ permalink raw reply related	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2025-06-06 18:59 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2025-06-05 18:12 [PATCH BlueZ v1 1/3] adapter: Fix exposing coordinate sets if LE Audio is disabled Luiz Augusto von Dentz
2025-06-05 18:12 ` [PATCH BlueZ v1 2/3] client: Add assistant.list Luiz Augusto von Dentz
2025-06-05 18:12 ` [PATCH BlueZ v1 3/3] client: Add assistant.show Luiz Augusto von Dentz
2025-06-05 20:09 ` [BlueZ,v1,1/3] adapter: Fix exposing coordinate sets if LE Audio is disabled bluez.test.bot
2025-06-06 19:00 ` [PATCH BlueZ v1 1/3] " patchwork-bot+bluetooth

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox